'use client';

import { useEffect, useState } from 'react';
import {
  Box,
  Button,
  Flex,
  Text,
  useColorModeValue,
  Link,
} from '@chakra-ui/react';
import NextLink from 'next/link';

export default function ConsentPopup() {
  const [show, setShow] = useState(false);

  useEffect(() => {
    const consent = localStorage.getItem('privacy-consent');
    if (!consent) {
      setShow(true);
    }
  }, []);

  const handleAccept = () => {
    localStorage.setItem('privacy-consent', 'true');
    setShow(false);
  };

  if (!show) return null;

  return (
    <Flex
      position="fixed"
      bottom={0}
      width="100%"
      bg={useColorModeValue('gray.100', 'gray.900')}
      p={4}
      boxShadow="md"
      alignItems="center"
      justifyContent="space-between"
      zIndex={1000}
    >
      <Text fontSize="sm" color={useColorModeValue('gray.800', 'gray.200')}>
        We use cookies to improve your experience. By using this site, you accept our{' '}
        <Link as={NextLink} href="/privacy-policy" color="teal.500" fontWeight="bold">
          Privacy Policy
        </Link>.
      </Text>

      <Button colorScheme="teal" size="sm" onClick={handleAccept}>
        Accept
      </Button>
    </Flex>
  );
}
